==> meerk-0.3.0-py3-none-any.whl: meerk/calendar/IcsCalendar.py <==
# MIT License
#
# Copyright (c) 2018 Alexey Nikitin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
import urllib.request
from datetime import datetime
from datetime import timedelta

from icalendar import Calendar as iCalendar

from meerk.intervals import Intervals
from .Calendar import Calendar


class IcsCalendar(Calendar):

    def __init__(self, url: str, intervals: Intervals):
        self.url = url
        self.intervals = intervals

    def is_busy(self, time: datetime) -> bool:
        return self.intervals.is_inside(time)

    def sync(self):
        response = urllib.request.urlopen(self.url)
        ical = response.read()
        self.intervals.clear()
        self.intervals.add(
            iCalendar.from_ical(ical).walk(),
            datetime.now() - timedelta(days=1),
            datetime.now() + timedelta(days=1)
        )

==> meerk-0.3.1-py3-none-any.whl: meerk/calendar/IcsCalendar.py <==
# MIT License
#
# Copyright (c) 2018 Alexey Nikitin
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
import urllib.request
from datetime import datetime
from datetime import timedelta

from icalendar import Calendar as iCalendar

from meerk.intervals import CalEventsIntervals
from .Calendar import Calendar


class IcsCalendar(Calendar):

    def __init__(self, url: str, intervals: CalEventsIntervals):
        self.url = url
        self.intervals = intervals

    def is_busy(self, time: datetime) -> bool:
        return self.intervals.is_inside(time)

    def sync(self):
        response = urllib.request.urlopen(self.url)
        ical = response.read()
        self.intervals.clear()
        self.intervals.add(
            iCalendar.from_ical(ical).walk(),
            datetime.now() - timedelta(days=1),
            datetime.now() + timedelta(days=1)
        )
